"use client";
import { useState, useEffect } from "react";
import { useSearchParams } from "next/navigation";
import AdminLayout from "@/components/admin/adminLayout";
import AgentWaitingApproval from "@/components/admin/admin_sidebar/TotalAgentsProperty/AgentWaitingApproval";
import AgentApprovedProperty from "@/components/admin/admin_sidebar/TotalAgentsProperty/AgentApprovedProperty";
import AgentRejectedProperty from "@/components/admin/admin_sidebar/TotalAgentsProperty/AgentRejectedProperty";
import axios from "@/services/APIservices";

export default function TotalAgentsPropertyPage() {
  const searchParams = useSearchParams();

  // State to store API data
  const [userAgentData, setUserAgentData] = useState([]);
  const [totalPostDetails, setTotalPostDetails] = useState(0);
  const [totalAgentPostDetails, setTotalAgentPostDetails] = useState(0);
  const [totalAgentUnapproval, setTotalAgentUnapproval] = useState(0);
  const [totalAgentApproval, setTotalAgentApproval] = useState(0);
  const [totalAgentRejected, setTotalAgentRejected] = useState(0);
  const [agentUsersData, setAgentUsersData] = useState([]);
  const [waitingAgentUsersData, setWaitingAgentUsersData] = useState([]);
  const [rejectedAgentUsersData, setRejectedAgentUsersData] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  // Mapping of view keys to components
  const viewComponents = {
    approved: AgentApprovedProperty,
    waiting: AgentWaitingApproval,
    rejected: AgentRejectedProperty,  
  };

  // Extract view from URL or default to 'approved'
  const currentView = searchParams.get("view") || "approved";

  // Dynamically select the component based on current view
  const SelectedComponent = viewComponents[currentView] || AgentApprovedProperty;

  // Function to fetch data from the API
  const fetchUserAgentData = async () => {
    try {
      const response = await axios.get("/api/user-agent-data");
      
      if (response.data.success) {
        setUserAgentData(response.data.data);
        setTotalPostDetails(response.data.totalPostDetails);
        setTotalAgentPostDetails(response.data.totalAgentPostDetails);
        setTotalAgentUnapproval(response.data.totalAgentUnapproval);
        setTotalAgentApproval(response.data.totalAgentApproval);
        setTotalAgentRejected(response.data.totalAgentRejected);
        setAgentUsersData(response.data.agentUsersData);
        setWaitingAgentUsersData(response.data.waitingAgentUsersData);
        setRejectedAgentUsersData(response.data.rejectedAgentUsersData);
        setError(null); // Clear any previous errors
      } else {
        setError(response.data.message || "Failed to fetch data.");
      }
    } catch (err) {
      setError(err.message || "An error occurred while fetching data.");
    } finally {
      setLoading(false); // Stop loading after fetch
    }
  };






  // New method to handle property status change
  const handlePropertyStatusChange = async (postId, statusType) => {
    try {
      let endpoint;
      if (statusType === 'waiting') {
        endpoint = `/api/user-agent-data/${postId}/waiting`;
      } else if (statusType === 'rejected') {
        endpoint = `/api/user-agent-data/${postId}/rejected`;
      } else if(statusType === 'approve') {
        endpoint = `/api/user-agent-data/${postId}/approve`;
      }

      const response = await axios.post(endpoint);
      
      if (response.data.success) {
        fetchUserAgentData(); // Refresh data after status change
      } else {
        setError(response.data.message || 'Failed to update status.');
      }
    } catch (err) {
      setError(err.message || 'An error occurred while updating status.');
    }
  };







  // Real-time data fetching using polling
  useEffect(() => {
    // Initial fetch
    fetchUserAgentData();

    // Set up polling interval
    const interval = setInterval(() => {
      fetchUserAgentData();
    }, 5000); // Fetch data every 5 seconds

    // Cleanup interval on component unmount
    return () => clearInterval(interval);
  }, []);

  // Show loading or error states if needed
  if (loading) {
    return (
      <AdminLayout>
        <div>Loading...</div>
      </AdminLayout>
    );
  }

  if (error) {
    return (
      <AdminLayout>
        <div>Error: {error}</div>
      </AdminLayout>
    );
  }

  return (
    <AdminLayout>
      {/* Render the selected component and pass down API data */}
      <SelectedComponent
        userAgentData={userAgentData}
        totalPostDetails={totalPostDetails}
        totalAgentPostDetails={totalAgentPostDetails}
        totalAgentUnapproval={totalAgentUnapproval}
        totalAgentApproval={totalAgentApproval}
        totalAgentRejected={totalAgentRejected}
        agentUsersData={agentUsersData}
        waitingAgentUsersData={waitingAgentUsersData}
        rejectedAgentUsersData={rejectedAgentUsersData}
        onStatusChange={handlePropertyStatusChange} // New prop for status change handler
      />
    </AdminLayout>
  );
}